misc/migration/postcreate.py
changeset 1977 606923dff11b
parent 1398 5fe84a5f7035
child 2172 cf8f9180e63e
--- a/misc/migration/postcreate.py	Thu May 28 08:06:12 2009 +0200
+++ b/misc/migration/postcreate.py	Thu May 28 09:20:07 2009 +0200
@@ -1,4 +1,10 @@
-"""cubicweb post creation script, set user's workflow"""
+"""cubicweb post creation script, set user's workflow
+
+:organization: Logilab
+:copyright: 2001-2009 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
+:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
+:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
+"""
 
 activatedeid = add_state(_('activated'), 'CWUser', initial=True)
 deactivatedeid = add_state(_('deactivated'), 'CWUser')